@@ -32,7 +32,8 @@ function(Xamp, DT=0.008, NEW=TRUE, STAMP=NULL)
 
     if(NEW==TRUE)
       {
-        get(getOption("device"))(width=15, height=10) 
+       ### get(getOption("device"))(width=15, height=10)
+        dev.new()
        ### X11(width=15, height=10)
       }
 ###  
