@@ -30,7 +30,9 @@ function(Xamp, DT=0.008, STAMP=NULL)
  
     NSEL = 1
 
-    get(getOption("device"))(width=15, height=10) 
+    ### get(getOption("device"))(width=15, height=10)
+       dev.new()
+       
    ###  X11(width=15, height=10)
 ###  
     WOUT =  wlet.do(Xamp, DT, noctave=7, zscale=scale.def,  col=pal, STAMP=STAMP)
